pub struct Xoshiro128PlusPlus { /* private fields */ }Expand description
A xoshiro128++ random number generator.
The xoshiro128++ algorithm is not suitable for cryptographic purposes, but is very fast and has excellent statistical properties.
The algorithm used here is translated from the xoshiro128plusplus.c
reference source code by
David Blackman and Sebastiano Vigna.