Xoshiro256PlusPlus

Struct Xoshiro256PlusPlus 

pub struct Xoshiro256PlusPlus { /* private fields */ }
A xoshiro256++ random number generator.

The xoshiro256++ algorithm is not suitable for cryptographic purposes, but is very fast and has excellent statistical properties.

The algorithm used here is translated from the xoshiro256plusplus.c reference source code by David Blackman and Sebastiano Vigna.